@@ -24,17 +24,15 @@ for which a new license (GPL+exception) is in place.
 #ifndef FONTCOMBO_H
 #define FONTCOMBO_H
 
-#include <qcombobox.h>
-#include <qlabel.h>
-#include <qlistbox.h>
-#include <qlayout.h>
-#include <qwidget.h>
-
+#include <QWidget>
+#include <QComboBox>
 #include "scribusapi.h"
-#include "scribusstructs.h"
-class QListBoxItem;
-class QFont;
 
+class QEvent;
+class QFont;
+class QGridLayout;
+class QPixmap;
+class QLabel;
 class ScribusDoc;
 class PrefsManager;
 
@@ -42,28 +40,13 @@ class PrefsManager;
   *@author Franz Schmid
   */
 
-class SCRIBUS_API FontListItem : public QListBoxItem
-{
-public:
-    FontListItem(QComboBox* parent, QString f, QFont fo);
-    virtual ~FontListItem() {};
-
-    virtual const int width(const QListBox *);
-    virtual const int height(const QListBox *);
-
-protected:
-    virtual void paint(QPainter *p);
-
-private:
-    QFont iFont;
-    QString fontName;
-};
-
-class SCRIBUS_API FontCombo : public QComboBox  
+class SCRIBUS_API FontCombo : public QComboBox
 {
 public:
 	FontCombo(QWidget* pa);
 	~FontCombo() {};
+	
+	
 
 	void RebuildList(ScribusDoc *currentDoc, bool forAnnotation = false, bool forSubstitute = false);
 private:
@@ -82,6 +65,9 @@ class SCRIBUS_API FontComboH : public QWidget
 public:
 	FontComboH(QWidget* parent, bool labels=false);
 	~FontComboH() {};
+	
+	virtual void changeEvent(QEvent *e);
+	
 	QString currentFont();
 	void RebuildList(ScribusDoc *currentDoc, bool forAnnotation = false, bool forSubstitute = false);
 
